@@ -22,7 +22,11 @@
 */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -54,7 +58,7 @@
 #include "image.h"
 #include "text.h"
 #include "paragraph.h"
-#include "spell.h"
+#include "spellchecker.h"
 #include "table.h"
 #include "template.h"
 
@@ -351,7 +355,7 @@ format_page_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cnam
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"),
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
 								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
@@ -369,7 +373,7 @@ format_text_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cnam
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"),
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
 								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
@@ -387,7 +391,7 @@ format_paragraph_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"),
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
 								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
@@ -575,6 +579,8 @@ menubar_update_format (GtkHTMLControlData *cd)
 
 		bonobo_ui_component_set_prop (uic, "/commands/InsertImage",
 					      "sensitive", sensitive, &ev);
+		bonobo_ui_component_set_prop (uic, "/commands/FormatPage",
+					      "sensitive", sensitive, &ev);
 		bonobo_ui_component_set_prop (uic, "/commands/InsertLink",
 					      "sensitive", sensitive, &ev);
 		bonobo_ui_component_set_prop (uic, "/commands/InsertRule",
@@ -657,6 +663,7 @@ menubar_set_languages (GtkHTMLControlData *cd)
 		g_string_printf (str, "/commands/SpellLanguage%d", i + 1);
 		bonobo_ui_component_set_prop (cd->uic, str->str, "state", enabled ? "1" : "0", NULL);
 	}
+	g_string_free (str, TRUE);
 	cd->block_language_changes = FALSE;
 }
 
@@ -783,6 +790,7 @@ menubar_setup (BonoboUIComponent  *uic,
 			bonobo_ui_component_set_prop (uic, pixmaps_map [i].path, "pixname", filename, NULL);
 		} else
 			g_warning ("cannot find icon: '%s' in gnome icon theme", pixmaps_map [i].stock_name);
+		g_free (filename);
 	}
 
 	spell_create_language_menu (cd);
