@@ -37,6 +37,7 @@
 #include "htmlcursor.h"
 #include "htmlobject.h"
 #include "htmltable.h"
+#include "htmltablecell.h"
 #include "htmltext.h"
 #include "htmltextslave.h"
 #include "htmlimage.h"
@@ -750,3 +751,32 @@ html_engine_set_title (HTMLEngine *e, const gchar *title)
 	e->title = g_string_new (title);
 	g_signal_emit_by_name (e, "title_changed");
 }
+
+void html_engine_edit_set_direction (HTMLEngine *e,
+				     HTMLDirection dir)
+{
+	HTMLClueFlow *cf = html_object_get_flow (e->cursor->object);
+
+	if (cf && cf->dir != dir && html_clueflow_is_empty (cf)) {
+		html_engine_freeze (e);
+		cf->dir = dir;
+		html_engine_thaw (e);
+	}
+}
+
+int
+html_engine_get_insert_level_for_object (HTMLEngine *e, HTMLObject *o)
+{
+	int cursor_level = 3, level = html_object_get_insert_level (o);
+
+	if (level > 3) {
+		if (e && e->cursor->object && e->cursor->object->parent && e->cursor->object->parent->parent && html_object_is_clue (e->cursor->object->parent->parent)) {
+			HTMLObject *clue = e->cursor->object->parent->parent;
+
+			while (clue && clue->parent && (HTML_IS_CLUEV (clue->parent) || HTML_IS_TABLE_CELL (clue->parent)))
+			       cursor_level ++;
+		}
+	}
+
+	return MIN (level, cursor_level);
+}
